import 'package:pmu/data/dto/page_dto.dart';
import 'package:pmu/data/mappers/user_mapper.dart';
import 'package:pmu/data/repositories/api_interface.dart';
import 'package:pmu/domain/models/card.dart';
import 'package:dio/dio.dart';
import 'package:pmu/domain/models/home.dart';
import 'package:pretty_dio_logger/pretty_dio_logger.dart';

class ApiRepository extends ApiInterface {
  static final Dio _dio = Dio()
    ..interceptors.add(PrettyDioLogger(requestHeader: true, requestBody: true));
  static const String _baseUrl = 'http://lovesearch-api.nspotapov.ru';

  @override
  Future<HomeData?> loadData({
    OnErrorCallback? onError,
    String? q,
    int pageNumber = 0,
    int itemsByPage = 5,
  }) async {
    try {
      const String url = '$_baseUrl/api/users/';
      final List<CardData> data = [];
      Map<String, dynamic> queryParameters = {
        'pageNumber': pageNumber,
        'itemsByPage': itemsByPage
      };
      if (q != null) {
        queryParameters['q'] = q;
      }
      final Response<dynamic> response = await _dio
          .get<Map<dynamic, dynamic>>(url, queryParameters: queryParameters);
      final PageDto pageDto =
          PageDto.fromJson(response.data as Map<String, dynamic>);
      int itemsCount = pageDto.itemsCount ?? 0;
      for (int i = 0; i < itemsCount; i++) {
        final CardData cardPost = pageDto.items![i].toDomain();
        data.add(cardPost);
      }

      HomeData homeData = HomeData(
          data: data,
          pageNumber: pageDto.pageNumber,
          nextPageNumber: pageDto.nextPageNumber);

      return homeData;
    } on DioException catch (e) {
      onError?.call(e.response?.statusMessage);
      onError?.call(e.error?.toString());
      return null;
    }
  }
}
